@@ -20,14 +20,40 @@ import os
 import sys
 import hashlib
 import tempfile
-import transaction
 from optparse import OptionParser
 from lovely.testlayers import util
 
+try:
+    import transaction
+except ImportError:
+    transaction = None
 
-#BASE = os.path.join(tempfile.gettempdir(), __name__)
 
-class BaseSQLScript(object):
+class ServerBase(object):
+
+    """Base class for abstracting sql servers"""
+
+    def resolveScriptPath(self, path):
+        return os.path.abspath(path)
+
+    def dbExists(self, dbName):
+        return dbName in self.listDatabases()
+
+    def isListening(self):
+        return self.isRunning()
+
+class ServerGetterMixin(object):
+
+    server_impl = None
+
+    @property
+    def srv(self):
+        assert self.server_impl, "No server implementation specified"
+        if not hasattr(self, '_srv'):
+            self._srv = self.server_impl(**self.srvArgs)
+        return self._srv
+
+class BaseSQLScript(ServerGetterMixin):
     """Base script to controll a sql server"""
 
     dbName = None
@@ -43,10 +69,6 @@ class BaseSQLScript(object):
         self.scripts = kwargs.pop('scripts', self.scripts)
         self.srvArgs.update(kwargs)
 
-    @property
-    def srv(self):
-        raise NotImplemented()
-
     def _setup(self, runscripts=False):
         self._checkListening()
         self._checkDBName()
@@ -110,7 +132,7 @@ class BaseSQLScript(object):
             sys.exit(1)
 
 
-class BaseSQLLayer(object):
+class BaseSQLLayer(ServerGetterMixin):
     """A test layer which creates a database and starts a sql server"""
 
     __bases__ = ()
@@ -120,6 +142,7 @@ class BaseSQLLayer(object):
 
     def __init__(self, dbName, scripts=[], setup=None, snapshotIdent=None):
         self.dbName = dbName
+        self.scripts_hash = self._gen_scripts_hash(scripts)
         self.scripts = scripts
         if setup is not None:
             self.setup = setup
@@ -131,12 +154,17 @@ class BaseSQLLayer(object):
 
     def _snapPath(self, ident):
         # dbname does not matter here
-        digest = hashlib.sha1(str(self.scripts)).hexdigest()
-        return os.path.join(self.base_path, '%s_%s.sql' % (digest, ident))
+        return os.path.join(self.base_path, '%s_%s.sql' % (
+            self.scripts_hash, ident))
 
-    @property
-    def srv(self):
-        raise NotImplemented()
+    def _gen_scripts_hash(self, scripts):
+        ident = []
+        for script in scripts:
+            path = self.srv.resolveScriptPath(script)
+            statinfo = os.stat(path)
+            ident.append((path, statinfo.st_mtime))
+        digest = hashlib.sha1(str(ident)).hexdigest()
+        return digest
 
     def snapshotInfo(self, ident):
         sp = self._snapPath(ident)
@@ -158,7 +186,11 @@ class BaseSQLLayer(object):
             self.srv.dropDB(self.dbName)
             self.srv.createDB(self.dbName)
             if self.scripts:
-                self.srv.runScripts(self.dbName, self.scripts)
+                try:
+                    self.srv.runScripts(self.dbName, self.scripts)
+                except:
+                    self.srv.stop()
+                    raise
             self.srv.dump(self.dbName, sp)
         # create the snapshot for app
         dirty = False
@@ -180,12 +212,13 @@ class BaseSQLLayer(object):
         self.firstTest = False
 
     def testTearDown(self):
-        try:
-            transaction.abort()
-        except AttributeError:
-            # we have no connection anymore, ignore
-            # XXX how to reproduce?
-            pass
+        if transaction is not None:
+            try:
+                transaction.abort()
+            except AttributeError:
+                # we have no connection anymore, ignore
+                # XXX how to reproduce?
+                pass
 
     def tearDown(self):
         self.firstTest = True
